(b64str->bigint string)(bigint->b64str length bi)(bytes->b64str bs)(calc-byte-length bi)Converts JCA private and public key to clojure map representing JWK object
Converts JCA private and public key to clojure map representing JWK object
(jwk->private-key jwk)Convert a jwk into a PrivateKey instance.
Convert a jwk into a PrivateKey instance.
(jwk->public-key jwk)Convert a jwk into a PublicKey instance.
Convert a jwk into a PublicKey instance.
Converts JCA public key to clojure map representing JWK object
Converts JCA public key to clojure map representing JWK object
(thumbprint jwk)Calculate the thumbprint of the jwk key according to the RFC7638.
Calculate the thumbprint of the jwk key according to the RFC7638.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |